Module freeze

Module freeze 

Structs

DifferentialCache

Enums

FreezeError

Functions

freeze_node
Freezes a node and its upstream dependencies into a WAV asset and returns a Patch to replace the subgraph with an AssetReaderNode.