pub fn freeze_node(
graph: &Graph,
target_node_id: StableId,
duration_secs: f32,
sample_rate: f32,
asset_path: &Path,
) -> Result<Patch, FreezeError>Expand description
Freezes a node and its upstream dependencies into a WAV asset and returns a Patch to replace the subgraph with an AssetReaderNode.